// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU LGPL license.

function errmsg = intprb_checklhs ( funname , lhs , lhsmin , lhsmax )
  // Generates an error if the number of LHS is not in bounds.
  //
  // Calling Sequence
  //   errmsg = intprb_checklhs ( funname , lhs , lhsmin , lhsmax )
  //
  // Parameters
  //   funname : a 1 x 1 matrix of strings, the name of the calling function.
  //   lhs : a 1 x 1 matrix of floating point integers, the actual number of output arguments
  //   lhsmin : a 1 x 1 matrix of floating point integers, the minimum number of output arguments
  //   lhsmax : a 1 x 1 matrix of floating point integers, the maximum number of output arguments
  //   errmsg : a 1 x 1 matrix of strings, the error message. If there was no error, the error message is the empty matrix.
  //
  // Description
  // This function is designed to be used to design functions with 
  // variable number of output arguments.
  // Notice that it is useless to call this function if the 
  // function definition does not use the varargout statement.
  //
  // Examples
  // // The function takes 3 input arguments and 0/1 output arguments
  // function varargout = myfunction ( x1 , x2 , x3 )
  //   [lhs, rhs] = argn()
  //   intprb_checkrhs ( "myfunction" , rhs , 3 , 3 )
  //   intprb_checklhs ( "myfunction" , lhs , 0 , 1 )
  //   y = x1 + x2 + x3
  //   if ( lhs >= 1 ) then
  //     varargout(1) = y
  //   end
  // endfunction
  // // Calling sequences which work
  // myfunction ( 1 , 2 , 3 )
  // y = myfunction ( 1 , 2 , 3 )
  // // Calling sequences which generate an error
  // [ y1 , y2 ] = myfunction ( 1 , 2 , 3 )
  // [ y1 , y2 , y3 ] = myfunction ( 1 , 2 , 3 )
  //
  // Authors
  //   Michael Baudin - 2010 - DIGITEO
  //
  
  errmsg = []
  if ( lhs < lhsmin | lhs > lhsmax ) then
    errmsg = msprintf(gettext("%s: Unexpected number of output arguments : %d provided while the number of expected output arguments is between %d and %d."), funname , lhs , lhsmin , lhsmax );
    error(errmsg)
  end
endfunction



