// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the GNU LGPL license.

function errmsg = intprb_checkrhs ( funname , rhs , rhsmin , rhsmax )
  // Generates an error if the number of RHS is not in bounds.
  //
  // Calling Sequence
  //   errmsg = intprb_checkrhs ( funname , rhs , rhsmin , rhsmax )
  //
  // Parameters
  //   funname : a 1 x 1 matrix of strings, the name of the calling function.
  //   rhs : a 1 x 1 matrix of floating point integers, the actual number of input arguments
  //   rhsmin : a 1 x 1 matrix of floating point integers, the minimum number of input arguments
  //   rhsmax : a 1 x 1 matrix of floating point integers, the maximum number of input arguments
  //   errmsg : a 1 x 1 matrix of strings, the error message. If there was no error, the error message is the empty matrix.
  //
  // Description
  // This function is designed to be used to design functions with 
  // variable number of input arguments.
  // Notice that it is useless to call this function if the 
  // function definition does not use the varargin statement.
  //
  // Examples
  // // The function takes 2/3 input arguments and 0/1 output arguments
  // function y = myfunction ( varargin )
  //   [lhs, rhs] = argn()
  //   intprb_checkrhs ( "myfunction" , rhs , 2 , 3 )
  //   intprb_checklhs ( "myfunction" , lhs , 0 , 1 )
  //   x1 = varargin(1)
  //   x2 = varargin(2)
  //   if ( rhs >= 3 ) then
  //     x3 = varargin(3)
  //   else
  //     x3 = 2
  //   end
  //   y = x1 + x2 + x3
  // endfunction
  // // Calling sequences which work
  // y = myfunction ( 1 , 2 )
  // y = myfunction ( 1 , 2 , 3 )
  // // Calling sequences which generate an error
  // y = myfunction ( 1 )
  // y = myfunction ( 1 , 2, 3, 4 )
  //
  // Authors
  //   Michael Baudin - 2010 - DIGITEO
  //

  errmsg = []
  if ( rhs < rhsmin | rhs > rhsmax ) then
    errmsg = msprintf(gettext("%s: Unexpected number of input arguments : %d provided while the number of expected input arguments is between %d and %d."), funname , rhs , rhsmin , rhsmax );
    error(errmsg)
  end
endfunction



